<?php

declare(strict_types=1);

namespace App\Middleware\Auth;

use App\Tools\PublicData;
use Hyperf\HttpServer\Contract\RequestInterface;
use Hyperf\HttpServer\Contract\ResponseInterface as HttpResponse;
use Psr\Container\ContainerInterface;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\MiddlewareInterface;
use Psr\Http\Server\RequestHandlerInterface;
use Hyperf\HttpMessage\Stream\SwooleStream;
use Hyperf\Di\Annotation\Inject;
use Hyperf\Redis\Redis;
class SensitiveMiddleware implements MiddlewareInterface
{
    protected ContainerInterface $container;

    protected RequestInterface $request;

    protected HttpResponse $response;
    #[Inject]
    protected Redis $redis;
    public function __construct( RequestInterface $request, HttpResponse $response)
    {
        $this->request = $request;
        $this->response = $response;
    }

    public function process(ServerRequestInterface $request, RequestHandlerInterface $handler): ResponseInterface
    {
        try {
            $badWords = $this->redis->sMembers('black_word'); //黑名单
            $whiteWords = $this->redis->sMembers('white_word');//白名单
            // 获取所有请求参数并拼接成文本
            $params = $this->request->all();
            $concatenated = "";
             if($params){
                  foreach ($params as $value) {
                      if (is_array($value)) {
                          // 如果值是数组，将数组元素用逗号连接
                          $concatenated.= implode(',', $value);
                      } else {
                          // 如果不是数组，直接拼接
                          $concatenated.= $value;
                      }
                  }
              }
            // 遍历违禁词，检查是否在文本中存在
            foreach ($badWords as $badWord) {
                // 判断该违禁词是否在白名单中，如果在则跳过
                if (in_array($badWord, $whiteWords)) {
                    continue;
                }
                if (str_contains($concatenated, $badWord)) {
                    // 处理找到违禁词的情况，例如返回错误信息
                    $message = '发现违禁词: '. $badWord;
                    return $this->response->json(
                        [
                            'code' => 0,
                            'data' => [],
                            'message' => $message
                        ]
                    );
                }
            }
          return $handler->handle($request);
        }catch (\Exception $e){
            return $this->response->json(
                [
                    'code' => $e->getCode(),
                    'data' => [],
                    'message' => '敏感词检测失败：'.$e->getMessage(),
                ]
            );
        }
        return false;
    }
}
